@@ -300,6 +300,10 @@ class EffectStatus(Enum):
     GLISTEN = "glisten"
     OPAL = "opal"
     PRISM = "prism"
+    UNDERWATER = "underwater"
+    COSMOS = "cosmos"
+    SUNBEAM = "sunbeam"
+    ENCHANT = "enchant"
     UNKNOWN = "unknown"
 
     @classmethod
@@ -348,6 +352,7 @@ class TimedEffectStatus(Enum):
 
     NO_EFFECT = "no_effect"
     SUNRISE = "sunrise"
+    SUNSET = "sunset"
     UNKNOWN = "unknown"
 
     @classmethod
@@ -718,8 +723,10 @@ class MotionSensingFeatureSensitivity:
     Used by `motion` and `camera_motion` resources.
     """
 
-    status: MotionSensingFeatureSensitivityStatus
     sensitivity: int
+    status: MotionSensingFeatureSensitivityStatus = (
+        MotionSensingFeatureSensitivityStatus.UNKNOWN
+    )
     sensitivity_max: int = 10
 
 
